Crate sshconfig_lint

Crate sshconfig_lint 

Modules

lexer
model
parser
report
resolve
rules

Functions

has_errors
Returns true if any finding has Error severity.
has_warnings
Returns true if any finding has Warning or Error severity.
lint_file
Lint an SSH config file by path, resolving Includes.
lint_file_no_includes
Lint an SSH config file by path, skipping Include resolution.
lint_str
Lint an SSH config from a string. Does not touch the filesystem.
lint_str_with_includes
Lint an SSH config from a string, with Include resolution against a base dir.