Module basic
sshconfig_
lint
0.4.0
Module basic
Module Items
Structs
In sshconfig_
lint::
rules
sshconfig_lint
::
rules
Module
basic
Structs

Deprecated
Weak
Algorithms
Duplicate
Directives
Duplicate
Host
Warns when multiple Host blocks have the same pattern.
Identity
File
Exists
Errors when an IdentityFile points to a file that doesn’t exist. Skips paths containing
%
or
${
(template variables).
Insecure
Option
Warns about directives that weaken SSH security.
Unsafe
Control
Path
Warns when
ControlPath
doesn’t include the tokens needed to uniquely identify connections. The OpenSSH man page recommends that ControlPath include at least
%h
,
%p
, and
%r
(or alternatively
%C
).
Wildcard
Host
Order
Warns when
Host *
appears before more specific Host blocks. In OpenSSH, first match wins, so
Host *
should usually come last.