Modules
Functions
- has_
errors - Returns true if any finding has Error severity.
- has_
warnings - Returns true if any finding has Warning or Error severity.
- lint_
file - Lint an SSH config file by path, resolving Includes.
- lint_
file_ no_ includes - Lint an SSH config file by path, skipping Include resolution.
- lint_
str - Lint an SSH config from a string. Does not touch the filesystem.
- lint_
str_ with_ includes - Lint an SSH config from a string, with Include resolution against a base dir.